==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Create spreadsheet</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Membuat spreadsheet yang baru</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Menyelaraskan bawah</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Bagian bawah menyelaraskan isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Pusat sejajar</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Bagian tengah menyelaraskan isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Rata Kiri</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Rata kiri isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Rata kanan</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Right-align isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Sejajarkan bagian atas</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Isi top-align dari sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Vertikal center-align</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Ekspor spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Ekspor spreadsheet ke file CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Impor spreadsheet</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Impor file CSV ke dalam spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Gabungkan sel</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Gabungkan sel yang dipilih di spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Setel alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Set alias untuk sel yang dipilih </translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Sel split</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Split sel gabungan sebelumnya di spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Teks tebal</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Tetapkan teks tebal di sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Teks miring</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Set italic text pada sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Garis bawahi teks</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Sifat sel</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Warna</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Teks</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Latar Belakang</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Penjajaran</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kiri</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Pusat</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Kanan</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Puncak</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Bawah</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Gaya</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Berani</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Miring</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Menggarisbawahi</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp; Unit tampilan</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias untuk sel ini</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Semua (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Impor file</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Ekspor file</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Isi sel</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Tampilkan spreadsheet</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Hitam</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Putih</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Merah</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Merah gelap</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>hijau</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Hijau tua</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Biru</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Biru tua</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Dark cyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta gelap</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Kuning</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Kuning gelap</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Abu-abu</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Abu-abu gelap</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Abu-abu muda</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Adat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Bentuk</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Isi</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Tanpa nama</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Sisipkan baris</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Hapus baris</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Sisipkan kolom</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Hapus kolom</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Properti ...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Create spreadsheet</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Membuat spreadsheet yang baru</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Menyelaraskan bawah</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Bagian bawah menyelaraskan isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Pusat sejajar</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Bagian tengah menyelaraskan isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Rata Kiri</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Rata kiri isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Rata kanan</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Right-align isi sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Sejajarkan bagian atas</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Isi top-align dari sel yang dipilih</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Vertikal center-align</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Ekspor spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Ekspor spreadsheet ke file CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Impor spreadsheet</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Impor file CSV ke dalam spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Gabungkan sel</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation type="unfinished">Merge selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Setel alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Set alias untuk sel yang dipilih </translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Sel split</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation type="unfinished">Split previously merged cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Teks tebal</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation type="unfinished">Set text in selected cells bold</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Teks miring</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation type="unfinished">Set text in selected cells italic</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Garis bawahi teks</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Gabungkan sel</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Sel split</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Sisipkan baris</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Hapus baris</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Sisipkan kolom</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Sifat sel</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Warna</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Teks</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Latar Belakang</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Penjajaran</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kiri</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Pusat</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Kanan</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Puncak</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Bawah</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Gaya</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Berani</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Miring</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Menggarisbawahi</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp; Unit tampilan</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias untuk sel ini</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Semua (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Impor file</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Ekspor file</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Tampilkan spreadsheet</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation type="unfinished">Spreadsheet does not support range selection when pasting.
Please select one cell only.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation type="unfinished">Copy &amp; Paste failed</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Hitam</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Putih</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Merah</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Merah gelap</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>hijau</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Hijau tua</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Biru</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Biru tua</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Dark cyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta gelap</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Kuning</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Kuning gelap</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Abu-abu</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Abu-abu gelap</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Abu-abu muda</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Bentuk</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Tanpa nama</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Sisipkan baris</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Hapus baris</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Sisipkan kolom</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Hapus kolom</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Properti ...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Indonesia</translation>
    </message>
  </context>
</TS>
